@@ -18,12 +18,14 @@
 # CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
 # TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
 # SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+from __future__ import annotations
 
 import base64
 import os
 import uuid
 
 from mailjet_rest import Client
+from majormode.perseus.model.email import Email
 
 from majormode.perseus.email.email_service import EmailServiceBase
 
@@ -36,7 +38,7 @@ class MailjetService(EmailServiceBase):
 
     @staticmethod
     def __build_attached_file_item(file_path_name: str) -> dict:
-        with open(file_path_name) as fd:
+        with open(file_path_name, 'rt') as fd:
             file_content = fd.read()
             file_base64_content = base64.b64encode(file_content.encode())
             file_name = os.path.basename(file_path_name)
@@ -44,7 +46,7 @@ class MailjetService(EmailServiceBase):
             attached_file_item = {
                 "Content-type": "text/plain",  # @todo: Implement binary file support
                 "Filename": file_name,
-                "content": file_base64_content,
+                "content": file_base64_content.decode(),
             }
 
             return attached_file_item
@@ -77,33 +79,43 @@ class MailjetService(EmailServiceBase):
             version=api_version or self.DEFAULT_MAILJET_VERSION)
 
     @classmethod
-    def __build_mailjet_data(cls, emails):
+    def __build_mailjet_data(cls, emails) -> dict:
         data = {
             'Messages': [
-                {
-                    'From': {
-                        'Email': email.author.email_address,
-                        'Name': email.author.name,
-                    },
-                    'To': [
-                        {
-                            'Email': recipient.email_address,
-                            'Name': recipient.name
-                        }
-                        for recipient in email.recipients
-                    ],
-                    'Subject': email.subject,
-                    'TextPart': email.text_content,
-                    'HTMLPart': email.html_content,
-                    'CustomID': uuid.uuid4().hex,
-                    'Attachments': email.attached_files and cls.__build_attached_file_item(email.attached_files),
-                }
+                cls.__build_message(email)
                 for email in emails
             ]
         }
 
         return data
 
+    @classmethod
+    def __build_message(cls, email: Email) -> dict:
+        message = {
+            'From': {
+                'Email': email.author.email_address,
+                'Name': email.author.name,
+            },
+            'To': cls.__build_recipients(email.recipients),
+            'Subject': email.subject,
+            'TextPart': email.text_content,
+            'HTMLPart': email.html_content,
+            'CustomID': uuid.uuid4().hex,
+            'Attachments': email.attached_files and cls.__build_attached_file_item(email.attached_files),
+        }
+
+        return message
+
+    @staticmethod
+    def __build_recipients(recipients: list | set | tuple) -> list:
+        return [
+            {
+                'Email': recipient.email_address,
+                'Name': recipient.name
+            }
+            for recipient in recipients
+        ]
+
     def send_emails(self, emails):
         emails = self._validate_emails(emails)
         data = self.__build_mailjet_data(emails)
